'use client';

import { useEffect, useState } from "react";
import { databases } from "../lib/appwrite";
import { databaseId, membersCollectionId } from "../lib/appwrite";
import { getCurrentUserWithRole } from "../utils/auth";
import { Query } from "appwrite";

// Import icons
const EditIcon = () => (
  <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5" viewBox="0 0 20 20" fill="currentColor">
    <path d="M13.586 3.586a2 2 0 112.828 2.828l-.793.793-2.828-2.828.793-.793zM11.379 5.793L3 14.172V17h2.828l8.38-8.379-2.83-2.828z" />
  </svg>
);

const DeleteIcon = () => (
  <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5" viewBox="0 0 20 20" fill="currentColor">
    <path fillRule="evenodd" d="M9 2a1 1 0 00-.894.553L7.382 4H4a1 1 0 000 2v10a2 2 0 002 2h8a2 2 0 002-2V6a1 1 0 100-2h-3.382l-.724-1.447A1 1 0 0011 2H9zM7 8a1 1 0 012 0v6a1 1 0 11-2 0V8zm5-1a1 1 0 00-1 1v6a1 1 0 102 0V8a1 1 0 00-1-1z" clipRule="evenodd" />
  </svg>
);

const SaveIcon = () => (
  <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5" viewBox="0 0 20 20" fill="currentColor">
    <path fillRule="evenodd" d="M16.707 5.293a1 1 0 010 1.414l-8 8a1 1 0 01-1.414 0l-4-4a1 1 0 011.414-1.414L8 12.586l7.293-7.293a1 1 0 011.414 0z" clipRule="evenodd" />
  </svg>
);

const CancelIcon = () => (
  <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5" viewBox="0 0 20 20" fill="currentColor">
    <path fillRule="evenodd" d="M4.293 4.293a1 1 0 011.414 0L10 8.586l4.293-4.293a1 1 0 111.414 1.414L11.414 10l4.293 4.293a1 1 0 01-1.414 1.414L10 11.414l-4.293 4.293a1 1 0 01-1.414-1.414L8.586 10 4.293 5.707a1 1 0 010-1.414z" clipRule="evenodd" />
  </svg>
);

// Confirmation Modal Component
const ConfirmationModal = ({ isOpen, onClose, onConfirm, title, message }) => {
  if (!isOpen) return null;

  return (
    <div className="fixed inset-0 bg-black bg-opacity-50 flex items-center justify-center z-50 p-4">
      <div className="bg-white rounded-lg shadow-xl max-w-md w-full">
        <div className="p-6">
          <h3 className="text-lg font-medium text-gray-900 mb-2">{title}</h3>
          <p className="text-gray-600 mb-6">{message}</p>
          
          <div className="flex justify-end space-x-3">
            <button
              onClick={onClose}
              className="px-4 py-2 border border-gray-300 rounded-md text-sm font-medium text-gray-700 hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-blue-500"
            >
              Cancel
            </button>
            <button
              onClick={onConfirm}
              className="px-4 py-2 bg-red-600 text-white rounded-md text-sm font-medium hover:bg-red-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-red-500"
            >
              Delete
            </button>
          </div>
        </div>
      </div>
    </div>
  );
};

export default function MemberList() {
  const [members, setMembers] = useState([]);
  const [currentUser, setCurrentUser] = useState(null);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState(null);
  const [editingId, setEditingId] = useState(null);
  const [editFormData, setEditFormData] = useState({
    name: '',
    email: '',
    phone: '',
    role: ''
  });
  const [showDeleteModal, setShowDeleteModal] = useState(false);
  const [memberToDelete, setMemberToDelete] = useState(null);

  useEffect(() => {
    const fetchData = async () => {
      try {
        const user = await getCurrentUserWithRole();
        setCurrentUser(user);

        const res = await databases.listDocuments(
          databaseId,
          membersCollectionId,
          [Query.orderDesc("$createdAt")]
        );
        
        setMembers(res.documents);
      } catch (err) {
        console.error("Error fetching data:", err);
        setError("Failed to load member data");
      } finally {
        setLoading(false);
      }
    };

    fetchData();
  }, []);

  const handleEditClick = (member) => {
    setEditingId(member.$id);
    setEditFormData({
      name: member.name,
      email: member.email,
      phone: member.phone,
      role: member.role
    });
  };

  const handleEditFormChange = (e) => {
    const { name, value } = e.target;
    setEditFormData({
      ...editFormData,
      [name]: value
    });
  };

  const handleUpdate = async (memberId) => {
    try {
      await databases.updateDocument(
        databaseId,
        membersCollectionId,
        memberId,
        editFormData
      );
      
      const res = await databases.listDocuments(
        databaseId,
        membersCollectionId,
        [Query.orderDesc("$createdAt")]
      );
      setMembers(res.documents);
      setEditingId(null);
    } catch (err) {
      console.error("Error updating member:", err);
      setError("Failed to update member");
    }
  };

  const handleDeleteClick = (memberId) => {
    setMemberToDelete(memberId);
    setShowDeleteModal(true);
  };

  const handleDeleteConfirm = async () => {
    if (!memberToDelete) return;
    
    try {
      await databases.deleteDocument(
        databaseId,
        membersCollectionId,
        memberToDelete
      );
      
      const res = await databases.listDocuments(
        databaseId,
        membersCollectionId,
        [Query.orderDesc("$createdAt")]
      );
      setMembers(res.documents);
    } catch (err) {
      console.error("Error deleting member:", err);
      setError("Failed to delete member");
    } finally {
      setShowDeleteModal(false);
      setMemberToDelete(null);
    }
  };

  if (loading) {
    return <div className="p-4">Loading members...</div>;
  }

  if (error) {
    return <div className="p-4 text-red-500">{error}</div>;
  }

  return (
    <div className="mt-8 p-4">
      <h2 className="text-xl font-semibold mb-4">All Members</h2>
      
      {currentUser && (
        <div className="mb-6 p-4 bg-blue-50 rounded-lg">
          <p className="font-medium">You are logged in as: {currentUser.name}</p>
          <p>Your role: <span className="capitalize font-semibold">{currentUser.role}</span></p>
        </div>
      )}

      <div className="overflow-x-auto">
        <table className="w-full border">
          <thead>
            <tr className="bg-gray-100">
              <th className="p-3 text-left">Name</th>
              <th className="p-3">Email</th>
              <th className="p-3">Phone</th>
              <th className="p-3">Join Date</th>
              <th className="p-3">Role</th>
              {currentUser?.role === 'admin' && <th className="p-3">Actions</th>}
            </tr>
          </thead>
          <tbody>
            {members.length > 0 ? (
              members.map((member) => (
                <tr key={member.$id} className="border-t hover:bg-gray-50">
                  {editingId === member.$id ? (
                    <>
                      <td className="p-3">
                        <input
                          type="text"
                          name="name"
                          value={editFormData.name}
                          onChange={handleEditFormChange}
                          className="border p-1 w-full"
                        />
                      </td>
                      <td className="p-3">
                        <input
                          type="email"
                          name="email"
                          value={editFormData.email}
                          onChange={handleEditFormChange}
                          className="border p-1 w-full"
                        />
                      </td>
                      <td className="p-3">
                        <input
                          type="text"
                          name="phone"
                          value={editFormData.phone}
                          onChange={handleEditFormChange}
                          className="border p-1 w-full"
                        />
                      </td>
                      <td className="p-3">
                        {member.joinDate ? new Date(member.joinDate).toLocaleDateString() : "N/A"}
                      </td>
                      <td className="p-3">
                        <select
                          name="role"
                          value={editFormData.role}
                          onChange={handleEditFormChange}
                          className="border p-1 w-full"
                        >
                          <option value="admin">Admin</option>
                          <option value="member">Member</option>
                        </select>
                      </td>
                      <td className="p-3 flex space-x-2">
                        <button
                          onClick={() => handleUpdate(member.$id)}
                          className="bg-green-500 text-white p-1.5 rounded hover:bg-green-600 transition"
                          title="Save"
                        >
                          <SaveIcon />
                        </button>
                        <button
                          onClick={() => setEditingId(null)}
                          className="bg-gray-500 text-white p-1.5 rounded hover:bg-gray-600 transition"
                          title="Cancel"
                        >
                          <CancelIcon />
                        </button>
                      </td>
                    </>
                  ) : (
                    <>
                      <td className="p-3">{member.name || "N/A"}</td>
                      <td className="p-3">{member.email || "N/A"}</td>
                      <td className="p-3">{member.phone || "N/A"}</td>
                      <td className="p-3">
                        {member.joinDate ? new Date(member.joinDate).toLocaleDateString() : "N/A"}
                      </td>
                      <td className="p-3 capitalize">
                        <span className={`px-2 py-1 rounded-full text-xs ${
                          member.role === "admin" 
                            ? "bg-purple-100 text-purple-800" 
                            : "bg-blue-100 text-blue-800"
                        }`}>
                          {member.role || "unknown"}
                        </span>
                      </td>
                      {currentUser?.role === 'admin' && (
                        <td className="p-3 flex space-x-2">
                          <button
                            onClick={() => handleEditClick(member)}
                            className="text-blue-500 hover:text-blue-700 p-1.5 rounded hover:bg-blue-50 transition"
                            title="Edit"
                          >
                            <EditIcon />
                          </button>
                          <button
                            onClick={() => handleDeleteClick(member.$id)}
                            className="text-red-500 hover:text-red-700 p-1.5 rounded hover:bg-red-50 transition"
                            title="Delete"
                          >
                            <DeleteIcon />
                          </button>
                        </td>
                      )}
                    </>
                  )}
                </tr>
              ))
            ) : (
              <tr>
                <td colSpan={currentUser?.role === 'admin' ? 6 : 5} className="p-4 text-center text-gray-500">
                  No members found
                </td>
              </tr>
            )}
          </tbody>
        </table>
      </div>

      <ConfirmationModal
        isOpen={showDeleteModal}
        onClose={() => setShowDeleteModal(false)}
        onConfirm={handleDeleteConfirm}
        title="Delete Member"
        message="Are you sure you want to delete this member? This action cannot be undone."
      />
    </div>
  );
}